@@ -21,7 +21,7 @@ use Image::ExifTool qw(:DataAccess :Utils);
 use Image::ExifTool::Exif;
 use Image::ExifTool::ASF;   # for GetGUID()
 
-$VERSION = '1.40';
+$VERSION = '1.41';
 
 sub ProcessFPX($$);
 sub ProcessFPXR($$$);
@@ -298,6 +298,7 @@ my %fpxFileType = (
 %Image::ExifTool::FlashPix::Main = (
     PROCESS_PROC => \&ProcessFPXR,
     GROUPS => { 2 => 'Image' },
+    VARS => { LONG_TAGS => 0 },
     NOTES => q{
         The FlashPix file format, introduced in 1996, was developed by Kodak,
         Hewlett-Packard and Microsoft.  Internally the FPX file structure mimics
@@ -480,6 +481,12 @@ my %fpxFileType = (
             return $val;
         },
     },
+    IeImg => {
+        Name => 'EmbeddedImage',
+        Notes => 'embedded images in Scene7 vignette VNT files',
+        Groups => { 2 => 'Preview' },
+        Binary => 1,
+    },
 );
 
 # Summary Information properties
@@ -1331,7 +1338,9 @@ sub ConvertDTTM($)
     my $hr  = ($val >> 6)  & 0x1f;
     my $min = ($val & 0x3f);
     $yr += 1900 if $val;
-    return sprintf("%.4d:%.2d:%.2d %.2d:%.2d:00%s",$yr,$mon,$day,$hr,$min,$val ? 'Z' : '');
+    # ExifTool 12.48 dropped the "Z" on the time here because a test .doc
+    # file written by Word 2011 on Mac certainly used local time here
+    return sprintf("%.4d:%.2d:%.2d %.2d:%.2d:00",$yr,$mon,$day,$hr,$min);
 }
 
 #------------------------------------------------------------------------------
@@ -2255,7 +2264,8 @@ sub ProcessFPX($$)
             # remove instance number or class ID from tag if necessary
             $tagInfo = $et->GetTagInfo($tagTablePtr, $1) if
                 ($tag =~ /(.*) \d{6}$/s and $$tagTablePtr{$1}) or
-                ($tag =~ /(.*)_[0-9a-f]{16}$/s and $$tagTablePtr{$1});
+                ($tag =~ /(.*)_[0-9a-f]{16}$/s and $$tagTablePtr{$1}) or
+                ($tag =~ /(.*)_[0-9]{4}$/s and $$tagTablePtr{$1});  # IeImg instances
         }
 
         my $lSib = Get32u(\$dir, $pos + 0x44);  # left sibling
@@ -2408,7 +2418,7 @@ JPEG images.
 
 =head1 AUTHOR
 
-Copyright 2003-2022, Phil Harvey (philharvey66 at gmail.com)
+Copyright 2003-2023, Phil Harvey (philharvey66 at gmail.com)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
